@@ -1,56 +1,54 @@
 #' A 'ggplot2' geom to add text labels to treemap tiles.
 #'
-#' `geom_treemap_text` can be used to add a text label to each tile in a treemap
-#' created with `geom_treemap`.
+#' `geom_treemap_text()` can be used to add a text label to each tile in a
+#' treemap created with `geom_treemap()`.
 #'
-#' `geom_treemap_text` requires `area` and `label` aesthetics. Several other
+#' `geom_treemap_text()` requires `area` and `label` aesthetics. Several other
 #' standard 'ggplot2' aesthetics are supported (see Aesthetics).
 #'
-#' `geom_treemap_text` uses the 'ggfittext' package to fit text to tiles. All
-#' text drawing options available in `ggfittext::geom_fit_text` (growing,
+#' `geom_treemap_text()` uses the 'ggfittext' package to fit text to tiles. All
+#' text drawing options available in `ggfittext::geom_fit_text()` (growing,
 #' reflowing, etc.) are also available here. For full details on how these
-#' options work, see the documentation for `ggfittext::geom_fit_text`.
+#' options work, see the documentation for `ggfittext::geom_fit_text()`.
 #'
 #' The `layout` argument is used to set the treemap layout algorithm. All
-#' `treemapify` geoms added to a plot should have the same value for `layout`
-#' and `start`, or they will not share a common layout (see `geom_treemap` for
-#' details on the layout algorithms).
+#' 'treemapify' geoms added to a plot should have the same value for `layout`
+#' and `start`, or they will not share a common layout (see `geom_treemap()`
+#' for details on the layout algorithms).
 #'
-#' @param padding.x,padding.y `grid::unit` object, giving horizontal or vertical
-#' padding between text and edge of tile. Defaults to 1 mm.
-#' @param place Where inside the box to place the text. Default is `bottom`;
-#' other options are `topleft`, `top`, `topright`, etc.
+#' @param padding.x,padding.y `grid::unit()` object, giving horizontal or
+#' vertical padding between text and edge of tile. Defaults to 1 mm.
+#' @param place Where inside the box to place the text. Default is 'bottom';
+#' other options are 'topleft', 'top', 'topright', etc.
 #' @param min.size Minimum font size, in points. If provided, text that would
 #' need to be shrunk below this size to fit the box will not be drawn. Defaults
 #' to 4 pt.
 #' @param grow If `TRUE`, text will be grown as well as shrunk to fill the box.
 #' @param reflow If `TRUE`, text will be reflowed (wrapped) to better fit the
 #' box.
-#' @param layout The layout algorithm, one of either "squarified" (the
-#' default), "scol", "srow" or "fixed". See Details for full details on the
+#' @param layout The layout algorithm, one of either 'squarified' (the
+#' default), 'scol', 'srow' or 'fixed'. See Details for full details on the
 #' different layout algorithms.
 #' @param start The corner in which to start placing the tiles. One of
 #' 'bottomleft' (the default), 'topleft', 'topright' or 'bottomright'.
 #' @param mapping,data,stat,position,na.rm,show.legend,inherit.aes,... Standard
-#' geom arguments as for `ggplot2::geom_text`.
+#' geom arguments as for `ggplot2::geom_text()`.
 #' @param fixed Deprecated. Use `layout = "fixed"` instead. Will be removed in
 #' later versions.
 #'
-#' @seealso geom_treemap
+#' @seealso [geom_treemap()]
 #'
 #' @section Aesthetics:
 #'
-#' \itemize{
-#'   \item area (required)
-#'   \item label (required)
-#'   \item subgroup, subgroup2 or subgroup3
-#'   \item colour
-#'   \item size
-#'   \item alpha
-#'   \item family
-#'   \item fontface
-#'   \item angle
-#' }
+#' - area (required)
+#' - label (required)
+#' - subgroup, subgroup2 or subgroup3
+#' - colour
+#' - size
+#' - alpha
+#' - family
+#' - fontface
+#' - angle
 #'
 #' @examples
 #'
@@ -156,6 +154,11 @@ GeomTreemapText <- ggplot2::ggproto(
     }
     data <- do.call(treemapify, params)
 
+    # Standardise the place argument
+    if (place %in% c("middle", "center")) {
+      place <- "centre"
+    }
+
     # Use ggfittext's fittexttree to draw text
     gt <- grid::gTree(
       data = data,
